@@ -8,15 +8,14 @@ import argparse
 import sys
 import datetime
 import time
-import six
 import simplejson
 from collections import defaultdict
 
 import logging
-if six.PY2:
-    from urlparse import urlparse
-else:
+try:
     from urllib.parse import urlparse
+except ImportError:
+    from urlparse import urlparse
 
 if sys.version_info < (2, 7):
     class NullHandler(logging.Handler):
@@ -605,7 +604,7 @@ def setup_parser():
     ###                    General options                ###
     #########################################################
 
-    parser = argparse.ArgumentParser(prog="copr")
+    parser = argparse.ArgumentParser(prog="copr", epilog="dummy text")
     # General connection options
 
     parser.add_argument("--debug", dest="debug", action="store_true",
